@@ -1,7 +1,6 @@
 import concurrent.futures
 import functools
 import itertools
-import logging
 import time
 import uuid
 from concurrent.futures import CancelledError
@@ -216,7 +215,6 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
             check_current_task_canceled()
 
             if docs is not None:
-
                 if isinstance(docs, BaseException):
                     if not isinstance(docs, CancelledError):
                         self._logger.exception(docs, exc_info=result)
@@ -340,7 +338,6 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
         self.ensure_workspace_loaded()
 
         while True:
-
             check_current_task_canceled()
 
             self.on_workspace_diagnostics_start(self)
@@ -363,9 +360,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
                 with self._logger.measure_time(
                     lambda: f"analyzing workspace for {len(documents)} documents",
                     context_name="workspace_diagnostics",
-                    level=logging.CRITICAL,
                 ):
-
                     self.on_workspace_diagnostics_analyze(self)
 
                     if self._break_diagnostics_loop_event.is_set():
@@ -402,10 +397,10 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
                                 folder = self.parent.workspace.get_workspace_folder(document.uri)
                                 name = path if folder is None else path.relative_to(folder.uri.to_path())
 
-                                progress.report(f"Analyze {i+1}/{len(documents)}: {name}", current=i + 1)
+                                progress.report(f"Analyze {i + 1}/{len(documents)}: {name}", current=i + 1)
                             elif analysis_mode == AnalysisProgressMode.SIMPLE:
                                 progress.begin()
-                                progress.report(f"Analyze {i+1}/{len(documents)}", current=i + 1)
+                                progress.report(f"Analyze {i + 1}/{len(documents)}", current=i + 1)
 
                             try:
                                 with self._current_diagnostics_task_lock:
@@ -447,7 +442,6 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
                 with self._logger.measure_time(
                     lambda: f"collect workspace diagnostic for {len(documents_to_collect)} documents",
                     context_name="collect_workspace_diagnostics",
-                    level=logging.CRITICAL,
                 ):
                     breaked = False
                     for document in set(documents) - set(documents_to_collect):
@@ -493,10 +487,10 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
                                 folder = self.parent.workspace.get_workspace_folder(document.uri)
                                 name = path if folder is None else path.relative_to(folder.uri.to_path())
 
-                                progress.report(f"Collect {i+1}/{len(documents_to_collect)}: {name}", current=i + 1)
+                                progress.report(f"Collect {i + 1}/{len(documents_to_collect)}: {name}", current=i + 1)
                             elif analysis_mode == AnalysisProgressMode.SIMPLE:
                                 progress.begin()
-                                progress.report(f"Collect {i+1}/{len(documents_to_collect)}", current=i + 1)
+                                progress.report(f"Collect {i + 1}/{len(documents_to_collect)}", current=i + 1)
 
                             try:
                                 with self._current_diagnostics_task_lock:
@@ -558,9 +552,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart):
         debounce: bool = True,
         send_diagnostics: bool = True,
     ) -> Task[Any]:
-
         with self.get_diagnostics_data(document) as data:
-
             if data.force or document.version != data.version or data.future is None or data.skipped_entries:
                 future = data.future
                 collect_slow = not data.single
